
# konsepy

Framework for build NLP information extraction systems using regular expressions.

## Usage

For now, find documentation for this library (and a template to download) from https://github.com/kpwhri/konsepy_nlp_template.


## Roadmap

* Change labels to some metadata object to allow more diverse input sources and run info
